@@ -6,10 +6,11 @@ from .flair_client import (FlairClient,)
 from .model import (FlairData, HVACUnit, HVACUnits, Puck, Pucks, Room,
                     Rooms, Schedule, Structure, Structures, Thermostat,
                     Thermostats, User, Users, Vent, Vents, Zone, Zones,)
+from .str_enum import StrEnum
 
 __all__ = ['Endpoint', 'FlairAuthError', 'FlairClient', 'FlairData',
            'FlairError', 'HVACUnit', 'HVACUnits', 'Header', 'Puck', 'Pucks',
-           'Reason', 'Room', 'Rooms', 'Schedule', 'Structure', 'Structures',
+           'Reason', 'Room', 'Rooms', 'Schedule', 'StrEnum', 'Structure', 'Structures',
            'TIMEOUT', 'Thermostat', 'Thermostats', 'User', 'Users', 'Vent',
            'Vents', 'Zone', 'Zones', 'constants', 'exceptions', 'flair_client',
            'model']
