@@ -1,9 +1,11 @@
-from enum import Enum
+"""Constant for FlairAIO"""
+
+from .str_enum import StrEnum
 
 TIMEOUT = 5 * 60
 
 # Endpoint URLs
-class Endpoint(str, Enum):
+class Endpoint(StrEnum):
     """Flair API endpoints."""
 
     BASE_URL = 'https://api.flair.co'
@@ -19,7 +21,7 @@ class Endpoint(str, Enum):
 
 
 # Headers constants
-class Header(str, Enum):
+class Header(StrEnum):
     """Flair client header constants."""
 
     CONTENT_ENCODED = 'application/x-www-form-urlencoded'
@@ -32,7 +34,7 @@ class Header(str, Enum):
 
 
 # Response error reason constants
-class Reason(str, Enum):
+class Reason(StrEnum):
     """Flair client response error reason constants."""
 
     CREATED = 'CREATED'
