@@ -49,17 +49,17 @@ class FlairClient:
         """
 
         headers = {
-            "content-type": f'{Header.CONTENT_ENCODED}'
+            "content-type": Header.CONTENT_ENCODED
         }
 
         data = {
-            f'{Header.CLIENT_ID}': self.client_id,
-            f'{Header.CLIENT_SECRET}': self.client_secret,
-            "scope": f'{Header.SCOPES}',
-            "grant_type": f'{Header.GRANT_TYPE}'
+            Header.CLIENT_ID: self.client_id,
+            Header.CLIENT_SECRET: self.client_secret,
+            "scope": Header.SCOPES,
+            "grant_type": Header.GRANT_TYPE
         }
 
-        response = await self._post(f'{Endpoint.AUTH_URL}', headers, data)
+        response = await self._post(Endpoint.AUTH_URL, headers, data)
         self.token = response['access_token']
         self.token_expiration = datetime.now() + timedelta(seconds=response['expires_in'])
 
@@ -82,7 +82,7 @@ class FlairClient:
     async def get_users(self) -> Users:
         """Get all users' information."""
 
-        fetched_users = await self._get(f'{Endpoint.USERS_URL}')
+        fetched_users = await self._get(Endpoint.USERS_URL)
         users: dict[str, User] = {}
         if fetched_users['data']:
             for user in fetched_users['data']:
@@ -107,7 +107,7 @@ class FlairClient:
     async def get_structures(self) -> Structures:
         """Get all structures."""
 
-        fetched_structures = await self._get(f'{Endpoint.STRUCTURES_URL}')
+        fetched_structures = await self._get(Endpoint.STRUCTURES_URL)
         structures: dict[str, Structure] = {}
 
         if fetched_structures['data']:
@@ -134,7 +134,7 @@ class FlairClient:
     async def get_rooms(self) -> Rooms:
         """Get all rooms."""
 
-        fetched_rooms = await self._get(f'{Endpoint.ROOMS_URL}')
+        fetched_rooms = await self._get(Endpoint.ROOMS_URL)
         rooms: dict[str, Room] = {}
 
         if fetched_rooms['data']:
@@ -160,7 +160,7 @@ class FlairClient:
     async def get_pucks(self) -> Pucks:
         """Get all pucks."""
 
-        fetched_pucks = await self._get(f'{Endpoint.PUCKS_URL}')
+        fetched_pucks = await self._get(Endpoint.PUCKS_URL)
         pucks: dict[str, Puck] = {}
 
         if fetched_pucks['data']:
@@ -186,7 +186,7 @@ class FlairClient:
     async def get_vents(self) -> Vents:
         """Get all vents."""
 
-        fetched_vents = await self._get(f'{Endpoint.VENTS_URL}')
+        fetched_vents = await self._get(Endpoint.VENTS_URL)
         vents: dict[str, Vent] = {}
 
         if fetched_vents['data']:
@@ -212,7 +212,7 @@ class FlairClient:
     async def get_thermostats(self) -> Thermostats:
         """Get all thermostats."""
 
-        fetched_thermostats = await self._get(f'{Endpoint.THERMOSTATS_URL}')
+        fetched_thermostats = await self._get(Endpoint.THERMOSTATS_URL)
         thermostats: dict[str, Thermostat] = {}
 
         if fetched_thermostats['data']:
@@ -238,7 +238,7 @@ class FlairClient:
     async def get_hvac_units(self) -> HVACUnits:
         """Get all HVAC units."""
 
-        fetched_hvacs = await self._get(f'{Endpoint.HVACS_URL}')
+        fetched_hvacs = await self._get(Endpoint.HVACS_URL)
         hvacs: dict[str, HVACUnit] = {}
 
         if fetched_hvacs['data']:
@@ -265,7 +265,7 @@ class FlairClient:
     async def get_zones(self) -> Zones:
         """Get all zones."""
 
-        fetched_zones = await self._get(f'{Endpoint.ZONES_URL}')
+        fetched_zones = await self._get(Endpoint.ZONES_URL)
         zones: dict[str, Zone] = {}
 
         if fetched_zones['data']:
@@ -338,8 +338,11 @@ class FlairClient:
                             relationships=puck['relationships'],
                             current_reading=None
                         )
-                        get_reading = await self.get_related(puck_object, 'current-reading')
-                        attributes = get_reading['attributes']
+                        if not puck['attributes']['inactive']:
+                            get_reading = await self.get_related(puck_object, 'current-reading')
+                            attributes = get_reading['attributes']
+                        else:
+                            attributes = {}
                         setattr(puck_object, 'current_reading', attributes)
                         pucks_data[puck['id']] = puck_object
 
@@ -352,8 +355,11 @@ class FlairClient:
                             relationships=vent['relationships'],
                             current_reading=None
                         )
-                        get_reading = await self.get_related(vent_object, 'current-reading')
-                        attributes = get_reading['attributes']
+                        if not vent['attributes']['inactive']:
+                            get_reading = await self.get_related(vent_object, 'current-reading')
+                            attributes = get_reading['attributes']
+                        else:
+                            attributes = {}
                         setattr(vent_object, 'current_reading', attributes)
                         vents_data[vent['id']] = vent_object
 
@@ -476,8 +482,8 @@ class FlairClient:
         """Create header for all GET calls."""
 
         headers = {
-            "content-type": f'{Header.CONTENT_ENCODED}',
-            "accept": f'{Header.ACCEPT}',
+            "content-type": Header.CONTENT_ENCODED,
+            "accept": Header.ACCEPT,
             "authorization": f'Bearer {self.token}'
         }
         return headers
@@ -486,7 +492,7 @@ class FlairClient:
         """Create json content-type header."""
 
         headers = {
-            "content-type": f'{Header.CONTENT_JSON}',
+            "content-type": Header.CONTENT_JSON,
             "authorization": f'Bearer {self.token}'
         }
         return headers
